import json
import logging
from http import HTTPStatus

import requests
from requests import Response, RequestException

from coin_sdk.common.securityservice import SecurityService
from coin_sdk.common.sendrequest import json2obj, RequestSender, ErrorHandler
from coin_sdk.mobile_connect.v3.mcconfig import MCConfig
from coin_sdk.mobile_connect.v3.domain.discovery_request import DiscoveryRequestV3
from coin_sdk.mobile_connect.v3.domain.discovery_response import DiscoveryResponseV3
from coin_sdk.mobile_connect.v3.domain.error_body import ErrorBody
from coin_sdk.mobile_connect.v3.domain.link import LinkDto
from coin_sdk.mobile_connect.v3.domain.supported_services import SupportedServicesDto

logger = logging.getLogger(__name__)


class DiscoveryRequestNoResultException(RequestException):
    """Discovery request did not yield any results"""

class DiscoveryRequestErrorHandler(ErrorHandler):

    def error_message_to_object(self, error_message):
        return ErrorBody(error_message.error, error_message.description, error_message.correlation_id)

    def on_connection_error(self, status: int, description: str, response: Response):
        raise requests.ConnectionError(f'HTTP Status: {status}, {description}', response=response)

    def on_not_found(self, error_object, response: Response):
        raise DiscoveryRequestNoResultException(f'HTTP Status: {HTTPStatus.NOT_FOUND}, {HTTPStatus.NOT_FOUND.description}', response=error_object)

    def on_other_error(self, status: int, description: str, response: Response):
        raise requests.HTTPError(f'HTTP Status: {status}, {description}', response=response)


def json_to_discovery_response_v3(json: dict[str, ...]):
    try:
        return DiscoveryResponseV3(**json) if 'supportedServices' in json else \
            SupportedServicesDto(**json) if 'accountTakeoverProtection' in json else LinkDto(**json)
    except AttributeError:
        return json2obj(json)


def discovery_response_parser(response: str) -> DiscoveryResponseV3:
    return json.loads(response, object_hook=json_to_discovery_response_v3)


class Sender:
    def __init__(self, config: MCConfig, error_handler=DiscoveryRequestErrorHandler()):
        self._config = config
        self._request_sender = RequestSender(
            security_service=SecurityService(config),
            error_handler=error_handler,
            object_parser=discovery_response_parser
        )

    def send_discovery_request(self, msisdn: str, correlation_id: str=None) -> DiscoveryResponseV3 | None:
        discovery_request = DiscoveryRequestV3(msisdn=msisdn, correlation_id=correlation_id)
        logger.info(f'Sending discovery request: {discovery_request}')
        message_dict = discovery_request.to_dict()
        try:
            return self._request_sender.send_request(requests.post, self._config.api_url, message_dict)
        except DiscoveryRequestNoResultException:
            return None



import logging
import time
from abc import abstractmethod, ABC
from json import JSONDecodeError
from typing import Type, Optional, Callable

import sseclient
from requests import ConnectionError
from requests.exceptions import ChunkedEncodingError, ReadTimeout

from coin_sdk.common.sendrequest import json2obj
from coin_sdk.number_portability.domain import MessageType, ConfirmationStatus
from coin_sdk.common.securityservice import SecurityService
from coin_sdk.number_portability.utils import get_stream, NumberPortabilityErrorHandler
from coin_sdk.number_portability.npconfig import NpConfig

logger = logging.getLogger(__name__)


class OffsetPersister(ABC):
    @abstractmethod
    def persist_offset(self, offset):
        pass

    @abstractmethod
    def get_persisted_offset(self):
        pass


class Receiver(ABC):
    class RetriesLeft:
        def __init__(self, config: NpConfig):
            self._config = config
            self._backoff_period = None
            self._number_of_retries = None
            self.reset()

        def reset(self):
            self._backoff_period = self._config._backoff_period
            self._number_of_retries = self._config._number_of_retries

        def get(self):
            return self._number_of_retries

        def __call__(self):
            return self._number_of_retries > 0

        def backoff(self):
            logger.warning(f'Trying to reconnect in {self._backoff_period} seconds. Retries left: {self.get()}')
            time.sleep(self._backoff_period)
            self._number_of_retries -= 1
            self._backoff_period = min(self._backoff_period*2, 60)

    def __init__(self, config: NpConfig):
        self._security_service = SecurityService(config)
        self._config = config
        self._offset_persister: Optional[OffsetPersister] = None
        self._recover_offset: Callable[[int], int] = lambda x: x
        self._running = None
        self._error_handler = NumberPortabilityErrorHandler()
        self._event_map = {
            MessageType.PORTING_REQUEST_V3.get_event_type(): self.on_porting_request,
            MessageType.PORTING_REQUEST_ANSWER_V3.get_event_type(): self.on_porting_request_answer,
            MessageType.PORTING_REQUEST_ANSWER_DELAYED_V3.get_event_type(): self.on_porting_request_answer_delayed,
            MessageType.PORTING_PERFORMED_V3.get_event_type(): self.on_porting_performed,
            MessageType.DEACTIVATION_V3.get_event_type(): self.on_deactivation,
            MessageType.CANCEL_V3.get_event_type(): self.on_cancel,
            MessageType.ERROR_FOUND_V3.get_event_type(): self.on_error_found,
            MessageType.ACTIVATION_SERVICE_NUMBER_V3.get_event_type(): self.on_activation_service_number,
            MessageType.DEACTIVATION_SERVICE_NUMBER_V3.get_event_type(): self.on_deactivation_service_number,
            MessageType.TARIFF_CHANGE_SERVICE_NUMBER_V3.get_event_type(): self.on_tariff_change_service_number,
            MessageType.RANGE_ACTIVATION_V3.get_event_type(): self.on_range_activation,
            MessageType.RANGE_DEACTIVATION_V3.get_event_type(): self.on_range_deactivation,

            MessageType.ENUM_ACTIVATION_NUMBER_V3.get_event_type(): self.on_enum_activation_number,
            MessageType.ENUM_ACTIVATION_OPERATOR_V3.get_event_type(): self.on_enum_activation_operator,
            MessageType.ENUM_ACTIVATION_RANGE_V3.get_event_type(): self.on_enum_activation_range,
            MessageType.ENUM_DEACTIVATION_NUMBER_V3.get_event_type(): self.on_enum_deactivation_number,
            MessageType.ENUM_DEACTIVATION_OPERATOR_V3.get_event_type(): self.on_enum_deactivation_operator,
            MessageType.ENUM_DEACTIVATION_RANGE_V3.get_event_type(): self.on_enum_deactivation_range,
            MessageType.ENUM_PROFILE_ACTIVATION_V3.get_event_type(): self.on_enum_profile_activation,
            MessageType.ENUM_PROFILE_DEACTIVATION_V3.get_event_type(): self.on_enum_profile_deactivation,
        }

    def start_stream(
            self,
            offset: int = None,
            confirmation_status: ConfirmationStatus = None,
            offset_persister: Type[OffsetPersister] = None,
            recover_offset: Callable[[int], int] = lambda x: x,
            message_types: [MessageType] = None
    ):
        self._running = True
        self._setup(confirmation_status, offset_persister, recover_offset)
        retries_left = self.RetriesLeft(self._config)
        while retries_left():
            try:
                self._connect(offset, confirmation_status, message_types, retries_left)
                return
            except (ConnectionError, ChunkedEncodingError, ReadTimeout) as e:
                # ChunkedEncodingError occurs when backend stops while waiting for new events
                if not(isinstance(e, ChunkedEncodingError)):
                    logger.warning(type(e).__name__)
                    logger.warning(e)
                if self._offset_persister:
                    offset = self._offset_persister.get_persisted_offset()
                    offset = self._recover_offset(offset)
                retries_left.backoff()
        logger.error("No retries left. Stopped consuming messages.")

    def _setup(
            self,
            confirmation_status: ConfirmationStatus,
            offset_persister: Type[OffsetPersister],
            recover_offset: Callable[[int], int]
    ):
        if confirmation_status == ConfirmationStatus.ALL and not offset_persister:
            raise ValueError('offset_persister should be given when confirmation_status equals ALL')
        if offset_persister and not issubclass(offset_persister, OffsetPersister):
            raise ValueError(f'offset_persister should be a subclass of {OffsetPersister.__module__}.OffsetPersister')
        self._offset_persister = offset_persister and offset_persister()
        self._recover_offset = recover_offset

    def _connect(self, offset: int, confirmation_status: ConfirmationStatus, message_types: [MessageType], retries_left: RetriesLeft):
        logger.debug('Opening stream')
        response = get_stream(self._config.sse_url, offset, confirmation_status, message_types, self._security_service)
        logger.debug(f'url: {response.request.url}')
        self._error_handler.handle_http_error(response)
        client = sseclient.SSEClient(response)
        retries_left.reset()
        self._consume_stream(client)

    def _consume_stream(self, client: sseclient.SSEClient):
        for event in client.events():
            if not self._running:
                return
            logger.debug('Received event')
            logger.debug(f'{event}')
            if event.data:
                self._process_event(event)
            else:
                self.on_keep_alive(event.id)
        logger.debug('Unexpected end of stream')
        raise ConnectionError()

    def stop(self):
        self._running = False

    def _process_event(self, event):
        try:
            event_type = event.event.lower()
            logger.debug(f'Event: {event.event}')
            message = json2obj(event.data).message
            logger.debug(f'Message: {message}')
            message_id = event.id
            logger.debug(f'Message id: {message_id}')
            event_handler = self._event_map.get(event_type, None)
            if event_handler:
                event_handler(message_id, message)
                self._persist_offset(message_id)
            else:
                logger.error(f"Number Portability Message with the following content isn't supported: {event}")
        except (JSONDecodeError, AttributeError):
            logger.error(f"Conversion of Number Portability Message failed for the following event: {event}")

    def _persist_offset(self, message_id):
        if self._offset_persister:
            self._offset_persister.persist_offset(message_id)

    @abstractmethod
    def on_keep_alive(self, message_id):
        pass

    @abstractmethod
    def on_porting_request(self, message_id, message):
        pass

    @abstractmethod
    def on_porting_request_answer(self, message_id, message):
        pass

    @abstractmethod
    def on_porting_request_answer_delayed(self, message_id, message):
        pass

    @abstractmethod
    def on_porting_performed(self, message_id, message):
        pass

    @abstractmethod
    def on_deactivation(self, message_id, message):
        pass

    @abstractmethod
    def on_cancel(self, message_id, message):
        pass

    @abstractmethod
    def on_error_found(self, message_id, message):
        pass

    @abstractmethod
    def on_activation_service_number(self, message_id, message):
        pass

    @abstractmethod
    def on_deactivation_service_number(self, message_id, message):
        pass

    @abstractmethod
    def on_tariff_change_service_number(self, message_id, message):
        pass

    @abstractmethod
    def on_range_activation(self, message_id, message):
        pass

    @abstractmethod
    def on_range_deactivation(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_activation_number(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_activation_range(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_activation_operator(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_deactivation_number(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_deactivation_range(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_deactivation_operator(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_profile_activation(self, message_id, message):
        pass

    @abstractmethod
    def on_enum_profile_deactivation(self, message_id, message):
        pass



import logging

import requests

from coin_sdk.common.securityservice import SecurityService
from coin_sdk.common.sendrequest import RequestSender
from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.message_response import MessageResponse
from coin_sdk.number_portability.npconfig import NpConfig
from coin_sdk.number_portability.utils import NumberPortabilityErrorHandler

logger = logging.getLogger(__name__)


class Sender:
    def __init__(self, config: NpConfig, error_handler=NumberPortabilityErrorHandler()):
        self._config = config
        self._request_sender = RequestSender(security_service=SecurityService(config), error_handler=error_handler)

    def _send_request(self, request, url, json):
        response_json = self._request_sender.send_request(request, url, json)
        try:
            return MessageResponse(response_json.transaction_id)
        except AttributeError:
            return response_json

    def send_message(self, message):
        logger.info(f'Sending message: {message}')
        message_type = message.get_message_type()
        message_dict = message.to_dict()
        url = f'{self._config.api_url}/{message_type.value}'
        logger.debug(f'url: {url}')
        return self._send_request(requests.post, url, message_dict)

    def confirm(self, transaction_id):
        logger.info(f'Sending confirmation for id: {transaction_id}')
        url = f'{self._config.api_url}/{MessageType.CONFIRMATION_V3.value}/{transaction_id}'
        logger.debug(f'url: {url}')
        json = {'transactionId': transaction_id}
        return self._send_request(requests.put, url, json)



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import HeaderCreator
from coin_sdk.number_portability.messages.enum.enum_profile_activation import EnumProfileActivation
from coin_sdk.number_portability.messages.message import Message
from .enum_profile_activation_body import EnumProfileActivationBody
from .enum_profile_activation_message import EnumProfileActivationMessage


class EnumProfileActivationBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._dossierid = None
        self._currentnetworkoperator = None
        self._typeofnumber = None

        self._scope = None
        self._profileid = None
        self._ttl = None
        self._dnsclass = None
        self._rectype = None
        self._order = None
        self._preference = None
        self._flags = None
        self._enumservice = None
        self._regexp = None
        self._usertag = None
        self._domain = None
        self._spcode = None
        self._processtype = None
        self._gateway = None
        self._service = None
        self._domaintag = None
        self._replacement = None

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_currentnetworkoperator(self, currentnetworkoperator: str):
        self._currentnetworkoperator = currentnetworkoperator
        return self

    def set_typeofnumber(self, typeofnumber: str):
        self._typeofnumber = typeofnumber
        return self

    def set_scope(self, scope: str):
        self._scope = scope
        return self

    def set_profileid(self, profileid: str):
        self._profileid = profileid
        return self

    def set_ttl(self, ttl: str):
        self._ttl = ttl
        return self

    def set_dnsclass(self, dnsclass: str):
        self._dnsclass = dnsclass
        return self

    def set_rectype(self, rectype: str):
        self._rectype = rectype
        return self

    def set_order(self, order: str):
        self._order = order
        return self

    def set_preference(self, preference: str):
        self._preference = preference
        return self

    def set_flags(self, flags: str):
        self._flags = flags
        return self

    def set_enumservice(self, enumservice: str):
        self._enumservice = enumservice
        return self

    def set_regexp(self, regexp: str):
        self._regexp = regexp
        return self

    def set_usertag(self, usertag: str):
        self._usertag = usertag
        return self

    def set_domain(self, domain: str):
        self._domain = domain
        return self

    def set_spcode(self, spcode: str):
        self._spcode = spcode
        return self

    def set_processtype(self, processtype: str):
        self._processtype = processtype
        return self

    def set_gateway(self, gateway: str):
        self._gateway = gateway
        return self

    def set_service(self, service: str):
        self._service = service
        return self

    def set_domaintag(self, domaintag: str):
        self._domaintag = domaintag
        return self

    def set_replacement(self, replacement: str):
        self._replacement = replacement
        return self

    def build(self):
        enum_activation_number = EnumProfileActivation(
            self._dossierid,
            self._currentnetworkoperator,
            self._typeofnumber,
            self._scope,
            self._profileid,
            self._ttl,
            self._dnsclass,
            self._rectype,
            self._order,
            self._preference,
            self._flags,
            self._enumservice,
            self._regexp,
            self._usertag,
            self._domain,
            self._spcode,
            self._processtype,
            self._gateway,
            self._service,
            self._domaintag,
            self._replacement,
        )
        body = EnumProfileActivationBody(enum_activation_number)
        message = EnumProfileActivationMessage(self._header, body)
        return Message(message, MessageType.ENUM_PROFILE_ACTIVATION_V3)



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import HeaderCreator, NumberSeries
from coin_sdk.number_portability.messages.message import Message
from .tariff_change_service_number import TariffChangeServiceNumber
from .tariff_change_service_number_seq import TariffChangeServiceNumberSeq
from .tariff_change_service_number_repeats import  TariffChangeServiceNumberRepeats
from .tariff_change_service_number_body import TariffChangeServiceNumberBody
from .tariff_change_service_number_message import  TariffChangeServiceNumberMessage
from ..tariffchangeservicenumber.tariff_info import TariffInfo


class TariffChangeServiceNumberBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._platformprovider = None
        self._planneddatetime = None
        self._dossierid = None
        self._note = None
        self._tariffChangeServiceNumber_seqs = []

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_platformprovider(self, platformprovider: str):
        self._platformprovider = platformprovider
        return self

    def set_planneddatetime(self, planneddatetime: str):
        self._planneddatetime = planneddatetime
        return self

    def set_note(self, note: str):
        self._note = note
        return self

    def add_tariffChangeServiceNumber_seq(self):
        return TariffChangeServiceNumberRepeatsBuilder(self)

    def build(self):
        repeats = [TariffChangeServiceNumberRepeats(seq) for seq in self._tariffChangeServiceNumber_seqs]
        tariffChangeServiceNumber = TariffChangeServiceNumber(
            self._dossierid,
            self._platformprovider,
            self._planneddatetime,
            repeats
        )
        body = TariffChangeServiceNumberBody(tariffChangeServiceNumber)
        message = TariffChangeServiceNumberMessage(self._header, body)
        return Message(message, MessageType.TARIFF_CHANGE_SERVICE_NUMBER_V3)


class TariffChangeServiceNumberRepeatsBuilder():
    def __init__(self, tariffChangeServiceNumber_builder: TariffChangeServiceNumberBuilder):
        super().__init__()
        self._tariffChangeServiceNumber_builder = tariffChangeServiceNumber_builder
        self._pop = None
        self._number_series = None
        self._tariff_info = None

    def set_number_series(self, start: str, end: str):
        self._number_series = NumberSeries(start, end)
        return self

    def set_tariff_info(self, peak: str, offPeak: str, currency: str, type: str, vat: str):
        tariffInfo = TariffInfo(peak, offPeak, currency, type, vat)
        self._tariff_info = tariffInfo
        return self

    def finish(self):
        seq = TariffChangeServiceNumberSeq(self._number_series, self._tariff_info)
        self._tariffChangeServiceNumber_builder._tariffChangeServiceNumber_seqs.append(seq)
        return self._tariffChangeServiceNumber_builder



from enum import Enum


class ConfirmationStatus(Enum):
    UNCONFIRMED = "Unconfirmed"
    ALL = "All"


class MessageType(Enum):
    ACTIVATION_SERVICE_NUMBER_V3 = "activationsn"
    CANCEL_V3 = "cancel"
    CONFIRMATION_V3 = "confirmations"
    DEACTIVATION_V3 = "deactivation"
    DEACTIVATION_SERVICE_NUMBER_V3 = "deactivationsn"
    ERROR_FOUND_V3 = "errorfound"
    ENUM_ACTIVATION_NUMBER_V3 = "enumactivationnumber"
    ENUM_ACTIVATION_OPERATOR_V3 = "enumactivationoperator"
    ENUM_ACTIVATION_RANGE_V3 = "enumactivationrange"
    ENUM_DEACTIVATION_NUMBER_V3 = "enumdeactivationnumber"
    ENUM_DEACTIVATION_OPERATOR_V3 = "enumdeactivationoperator"
    ENUM_DEACTIVATION_RANGE_V3 = "enumdeactivationrange"
    ENUM_PROFILE_ACTIVATION_V3 = "enumprofileactivation"
    ENUM_PROFILE_DEACTIVATION_V3 = "enumprofiledeactivation"
    PORTING_REQUEST_V3 = "portingrequest"
    PORTING_REQUEST_ANSWER_V3 = "portingrequestanswer"
    PORTING_PERFORMED_V3 = "portingperformed"
    PORTING_REQUEST_ANSWER_DELAYED_V3 = "pradelayed"
    RANGE_ACTIVATION_V3 = "rangeactivation"
    RANGE_DEACTIVATION_V3 = "rangedeactivation"
    TARIFF_CHANGE_SERVICE_NUMBER_V3 = "tariffchangesn"
    _VERSION_SUFFIX_V3 = "-v3"

    def get_event_type(self):
        return f'{self.value}{self._VERSION_SUFFIX_V3.value}'



import json
import logging
from abc import ABC, abstractmethod
from collections import namedtuple
from http import HTTPStatus
from json import JSONDecodeError
from typing import Callable

import requests
from requests import Response

from coin_sdk.common.securityservice import SecurityService

logger = logging.getLogger(__name__)


def _json_object_hook(d):
    return namedtuple('obj', d.keys())(*d.values())


def json2obj(data: str):
    try:
        return json.loads(data, object_hook=_json_object_hook)
    except JSONDecodeError:
        return data


class ErrorHandler(ABC):
    def handle_http_error(self, response: Response):
        logger.debug('Checking for errors')
        status = response.status_code
        logger.debug(f'Http Status: {status}')
        if status == HTTPStatus.OK:
            return
        description = HTTPStatus(status).description
        if status == HTTPStatus.BAD_GATEWAY or status == HTTPStatus.SERVICE_UNAVAILABLE or status == HTTPStatus.GATEWAY_TIMEOUT:
            self.on_connection_error(status, description, response)

        logger.error(f'Error: {response.text}')
        try:
            error_message = json2obj(response.text)
            error_object = self.error_message_to_object(error_message)
            if status == HTTPStatus.NOT_FOUND:
                self.on_not_found(error_object, response)
            raise requests.HTTPError(f'HTTP Status: {status}, {description}\n{str(error_object)}',
                                     response=error_object)
        except AttributeError:
            logger.error(response)
            self.on_other_error(status, description, response)

    @abstractmethod
    def error_message_to_object(self, error_message):
        pass

    @abstractmethod
    def on_connection_error(self, status: int, description: str, response: Response):
        pass

    @abstractmethod
    def on_not_found(self, error_object, response: Response):
        pass

    @abstractmethod
    def on_other_error(self, status: int, description: str, response: Response):
        pass


class RequestSender:
    def __init__(
            self,
            security_service: SecurityService,
            error_handler: ErrorHandler,
            object_parser=json2obj
    ):
        self._security_service = security_service
        self._error_handler = error_handler
        self._object_parser = object_parser

    def send_request(
            self,
            request: Callable[..., Response],
            url: str,
            json: dict[str, str]
    ):
        method = request.__name__
        headers = self._security_service.generate_headers(url, method, json)
        cookie = self._security_service.generate_jwt()
        logger.debug(f'Making request: {method}')
        response = request(url, json=json, headers=headers, cookies=cookie)
        logger.debug(f'Header: {response.request.headers}')
        logger.debug(f'Body: {response.request.body}')
        self._error_handler.handle_http_error(response)
        logger.debug('Converting JSON response to Python')
        response_json = self._object_parser(response.text)
        logger.debug(f'Response: {response_json}')
        return response_json


# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re

import six


class PortingRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dossierid': 'str',
        'recipientserviceprovider': 'str',
        'recipientnetworkoperator': 'str',
        'donornetworkoperator': 'str',
        'donorserviceprovider': 'str',
        'customerinfo': 'CustomerInfo',
        'contract': 'str',
        'note': 'str',
        'repeats': 'list[PortingRequestRepeats]'
    }

    attribute_map = {
        'dossierid': 'dossierid',
        'recipientserviceprovider': 'recipientserviceprovider',
        'recipientnetworkoperator': 'recipientnetworkoperator',
        'donornetworkoperator': 'donornetworkoperator',
        'donorserviceprovider': 'donorserviceprovider',
        'customerinfo': 'customerinfo',
        'contract': 'contract',
        'note': 'note',
        'repeats': 'repeats'
    }

    def __init__(self, dossierid=None, recipientserviceprovider=None, recipientnetworkoperator=None, donornetworkoperator=None, donorserviceprovider=None, customerinfo=None, contract=None, note=None, repeats=None):
        """PortingRequest - a model defined in Swagger"""
        self._dossierid = None
        self._recipientserviceprovider = None
        self._recipientnetworkoperator = None
        self._donornetworkoperator = None
        self._donorserviceprovider = None
        self._customerinfo = None
        self._contract = None
        self._note = None
        self._repeats = None
        self.discriminator = None
        self.dossierid = dossierid
        if recipientserviceprovider is not None:
            self.recipientserviceprovider = recipientserviceprovider
        self.recipientnetworkoperator = recipientnetworkoperator
        if donornetworkoperator is not None:
            self.donornetworkoperator = donornetworkoperator
        if donorserviceprovider is not None:
            self.donorserviceprovider = donorserviceprovider
        if customerinfo is not None:
            self.customerinfo = customerinfo
        if contract is not None:
            self.contract = contract
        if note is not None:
            self.note = note
        self.repeats = repeats

    @property
    def dossierid(self):
        """Gets the dossierid of this PortingRequest.


        :return: The dossierid of this PortingRequest.
        :rtype: str
        """
        return self._dossierid

    @dossierid.setter
    def dossierid(self, dossierid):
        """Sets the dossierid of this PortingRequest.


        :param dossierid: The dossierid of this PortingRequest.
        :type: str
        """
        if dossierid is None:
            raise ValueError("Invalid value for `dossierid`, must not be `None`")
        if dossierid is not None and not re.search(r'[-0-9A-Z]{5,26}', dossierid):
            raise ValueError(r"Invalid value for `dossierid`, must be a follow pattern or equal to `/[-0-9A-Z]{5,26}/`")

        self._dossierid = dossierid

    @property
    def recipientserviceprovider(self):
        """Gets the recipientserviceprovider of this PortingRequest.


        :return: The recipientserviceprovider of this PortingRequest.
        :rtype: str
        """
        return self._recipientserviceprovider

    @recipientserviceprovider.setter
    def recipientserviceprovider(self, recipientserviceprovider):
        """Sets the recipientserviceprovider of this PortingRequest.


        :param recipientserviceprovider: The recipientserviceprovider of this PortingRequest.
        :type: str
        """
        if recipientserviceprovider is not None and not re.search(r'[0-9A-Z]{3,6}', recipientserviceprovider):  # noqa: E501
            raise ValueError(r"Invalid value for `recipientserviceprovider`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._recipientserviceprovider = recipientserviceprovider

    @property
    def recipientnetworkoperator(self):
        """Gets the recipientnetworkoperator of this PortingRequest.


        :return: The recipientnetworkoperator of this PortingRequest.
        :rtype: str
        """
        return self._recipientnetworkoperator

    @recipientnetworkoperator.setter
    def recipientnetworkoperator(self, recipientnetworkoperator):
        """Sets the recipientnetworkoperator of this PortingRequest.


        :param recipientnetworkoperator: The recipientnetworkoperator of this PortingRequest.
        :type: str
        """
        if recipientnetworkoperator is None:
            raise ValueError("Invalid value for `recipientnetworkoperator`, must not be `None`")  # noqa: E501
        if recipientnetworkoperator is not None and not re.search(r'[0-9A-Z]{3,6}', recipientnetworkoperator):  # noqa: E501
            raise ValueError(r"Invalid value for `recipientnetworkoperator`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._recipientnetworkoperator = recipientnetworkoperator

    @property
    def donornetworkoperator(self):
        """Gets the donornetworkoperator of this PortingRequest.


        :return: The donornetworkoperator of this PortingRequest.
        :rtype: str
        """
        return self._donornetworkoperator

    @donornetworkoperator.setter
    def donornetworkoperator(self, donornetworkoperator):
        """Sets the donornetworkoperator of this PortingRequest.


        :param donornetworkoperator: The donornetworkoperator of this PortingRequest.
        :type: str
        """
        if donornetworkoperator is not None and not re.search(r'[0-9A-Z]{3,6}', donornetworkoperator):  # noqa: E501
            raise ValueError(r"Invalid value for `donornetworkoperator`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._donornetworkoperator = donornetworkoperator

    @property
    def donorserviceprovider(self):
        """Gets the donorserviceprovider of this PortingRequest.


        :return: The donorserviceprovider of this PortingRequest.
        :rtype: str
        """
        return self._donorserviceprovider

    @donorserviceprovider.setter
    def donorserviceprovider(self, donorserviceprovider):
        """Sets the donorserviceprovider of this PortingRequest.


        :param donorserviceprovider: The donorserviceprovider of this PortingRequest.
        :type: str
        """
        if donorserviceprovider is not None and not re.search(r'[0-9A-Z]{3,6}', donorserviceprovider):  # noqa: E501
            raise ValueError(r"Invalid value for `donorserviceprovider`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._donorserviceprovider = donorserviceprovider

    @property
    def customerinfo(self):
        """Gets the customerinfo of this PortingRequest.


        :return: The customerinfo of this PortingRequest.
        :rtype: CustomerInfo
        """
        return self._customerinfo

    @customerinfo.setter
    def customerinfo(self, customerinfo):
        """Sets the customerinfo of this PortingRequest.


        :param customerinfo: The customerinfo of this PortingRequest.
        :type: CustomerInfo
        """

        self._customerinfo = customerinfo

    @property
    def contract(self):
        """Gets the contract of this PortingRequest.


        :return: The contract of this PortingRequest.
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this PortingRequest.


        :param contract: The contract of this PortingRequest.
        :type: str
        """

        if contract is not None and not re.search(r'^(EARLY_TERMINATION|CONTINUATION)$', contract):
            raise ValueError(r"Invalid value for `contract`, must be `EARLY_TERMINATION` or `CONTINUATION`")

        self._contract = contract

    @property
    def note(self):
        """Gets the note of this PortingRequest.


        :return: The note of this PortingRequest.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PortingRequest.


        :param note: The note of this PortingRequest.
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `100`")  # noqa: E501
        if note is not None and len(note) < 1:
            raise ValueError("Invalid value for `note`, length must be greater than or equal to `1`")  # noqa: E501

        self._note = note

    @property
    def repeats(self):
        """Gets the repeats of this PortingRequest.


        :return: The repeats of this PortingRequest.
        :rtype: list[PortingRequestRepeats]
        """
        return self._repeats

    @repeats.setter
    def repeats(self, repeats):
        """Sets the repeats of this PortingRequest.


        :param repeats: The repeats of this PortingRequest.
        :type: list[PortingRequestRepeats]
        """
        if repeats is None:
            raise ValueError("Invalid value for `repeats`, must not be `None`")

        self._repeats = repeats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortingRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import CustomerInfo, EnumRepeatsBuilder, HeaderCreator
from coin_sdk.number_portability.messages.common.enum_repeats_builder import EnumOperatorBuilder
from coin_sdk.number_portability.messages.enum.enum_content import EnumContent
from coin_sdk.number_portability.messages.enum.enum_operator_seq import EnumOperatorSeq
from coin_sdk.number_portability.messages.message import Message
from .enum_deactivation_operator_body import EnumDeactivationOperatorBody
from .enum_deactivation_operator_message import EnumDeactivationOperatorMessage
from .enum_number_repeats import EnumNumberRepeats
from .enum_number_seq import EnumNumberSeq


class EnumDeactivationOperatorBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._dossierid = None
        self._currentnetworkoperator = None
        self._typeofnumber = None
        self._enum_deactivation_operator_seqs = []

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_currentnetworkoperator(self, currentnetworkoperator: str):
        self._currentnetworkoperator = currentnetworkoperator
        return self

    def set_typeofnumber(self, typeofnumber: str):
        self._typeofnumber = typeofnumber
        return self

    def add_enum_deactivation_operator_seq(self):
        return EnumDeactivationOperatorRepeatsBuilder(self)

    def build(self):
        repeats = [EnumNumberRepeats(seq) for seq in self._enum_deactivation_operator_seqs]
        enum_deactivation_operator = EnumContent(
            self._dossierid,
            self._currentnetworkoperator,
            self._typeofnumber,
            repeats
        )
        body = EnumDeactivationOperatorBody(enum_deactivation_operator)
        message = EnumDeactivationOperatorMessage(self._header, body)
        return Message(message, MessageType.ENUM_DEACTIVATION_OPERATOR_V3)


class EnumDeactivationOperatorRepeatsBuilder(EnumOperatorBuilder):
    def __init__(self, enum_deactivation_operator_builder: EnumDeactivationOperatorBuilder):
        super().__init__()
        self._enum_deactivation_operator_builder = enum_deactivation_operator_builder

    def set_profileid(self, profileid: str):
        self._set_profileid(profileid)
        return self

    def set_default_service(self, default_service: str):
        self._set_defaultservice(default_service)
        return self

    def finish(self):
        seq = EnumOperatorSeq(self._profileid, self._defaultservice)
        self._enum_deactivation_operator_builder._enum_deactivation_operator_seqs.append(seq)
        return self._enum_deactivation_operator_builder



import logging
import urllib.parse

import requests
from requests import Response

from coin_sdk.common.securityservice import SecurityService
from coin_sdk.common.sendrequest import ErrorHandler
from coin_sdk.number_portability.domain import ConfirmationStatus, MessageType
from coin_sdk.number_portability.messages.common import ErrorMessages

logger = logging.getLogger(__name__)


class NumberPortabilityErrorHandler(ErrorHandler):

    def error_message_to_object(self, error_message):
        ErrorMessages(error_message.transactionId, error_message.errors)

    def on_connection_error(self, status: int, description: str, response: Response):
        raise requests.ConnectionError(f'HTTP Status: {status}, {description}', response=response)

    def on_not_found(self, error_object, response: Response):
        pass

    def on_other_error(self, status: int, description: str, response: Response):
        raise requests.HTTPError(f'HTTP Status: {status}, {description}', response=response)


def get_stream(url: str, offset: int, confirmation_status: ConfirmationStatus, message_types: [MessageType], security_service: SecurityService):
    params = {
        'offset': offset,
        'messageTypes': message_types and ','.join([message_type.value for message_type in message_types]),
        'confirmationStatus': confirmation_status and confirmation_status.value
    }
    params = {k: v for k, v in params.items() if v is not None}
    full_url = f'{url}?{urllib.parse.urlencode(params)}'

    headers = security_service.generate_headers(full_url)
    cookie = security_service.generate_jwt()
    return requests.get(full_url, stream=True, headers=headers, cookies=cookie, timeout=(15,25))



import os
import unittest

from coin_sdk.mobile_connect.v3.mcconfig import MCConfig
from coin_sdk.mobile_connect.v3.domain.error_body import ErrorBody
from coin_sdk.mobile_connect.v3.sender import Sender

config = MCConfig(
    os.getenv('CRDB_REST_BACKEND', 'http://0.0.0.0:8000'),
    'loadtest-loada',
    private_key_file='./test/setup/private-key.pem',
    hmac_secret='./test/setup/sharedkey.encrypted'
)

sender = Sender(config)


class MobileConnectTest(unittest.TestCase):

    def test_discovery_request(self):
        response = sender.send_discovery_request(msisdn='123456789')
        self.assertIsNotNone(response)

    def test_discovery_request_not_found(self):
        response = sender.send_discovery_request(msisdn='123456789', correlation_id='404')
        self.assertIsNone(response)

    def test_discovery_request_other_error(self):
        with self.assertRaises(Exception) as context:
            sender.send_discovery_request(msisdn='123456789', correlation_id='403')
        self.assertIsInstance(context.exception.response, ErrorBody)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat

from six import iteritems


class EnumDeactivationRangeMessage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'header': 'Header',
        'body': 'EnumDeactivationRangeBody'
    }

    attribute_map = {
        'header': 'header',
        'body': 'body'
    }

    def __init__(self, header=None, body=None):
        """EnumDeactivationRangeMessage - a model defined in Swagger"""
        self._header = None
        self._body = None
        self.discriminator = None
        self.header = header
        self.body = body

    @property
    def header(self):
        """Gets the header of this EnumDeactivationRangeMessage.


        :return: The header of this EnumDeactivationRangeMessage.
        :rtype: Header
        """
        return self._header

    @header.setter
    def header(self, header):
        """Sets the header of this EnumDeactivationRangeMessage.


        :param header: The header of this EnumDeactivationRangeMessage.
        :type: Header
        """
        if header is None:
            raise ValueError("Invalid value for `header`, must not be `None`")

        self._header = header

    @property
    def body(self):
        """Gets the body of this EnumDeactivationRangeMessage.


        :return: The body of this EnumDeactivationRangeMessage.
        :rtype: EnumDeactivationRangeBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EnumDeactivationRangeMessage.


        :param body: The body of this EnumDeactivationRangeMessage.
        :type: EnumDeactivationRangeBody
        """
        if body is None:
            raise ValueError("Invalid value for `body`, must not be `None`")

        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnumDeactivationRangeMessage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnumDeactivationRangeMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    COIN Mobile Connect Rest API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 3
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DiscoveryRequestV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'msisdn': 'str',
        'correlation_id': 'str'
    }

    attribute_map = {
        'msisdn': 'msisdn',
        'correlation_id': 'correlationId'
    }

    def __init__(self, msisdn:str=None, correlation_id:str=None):  # noqa: E501
        """DiscoveryRequestV3 - a model defined in Swagger"""  # noqa: E501
        self._msisdn = None
        self._correlation_id = None
        self.discriminator = None
        self.msisdn = msisdn
        if correlation_id is not None:
            self.correlation_id = correlation_id

    @property
    def msisdn(self):
        """Gets the msisdn of this DiscoveryRequestV3.  # noqa: E501

        Mobile number in the international dialing format either 31600000000, +31600000000 or 0031600000000  # noqa: E501

        :return: The msisdn of this DiscoveryRequestV3.  # noqa: E501
        :rtype: str
        """
        return self._msisdn

    @msisdn.setter
    def msisdn(self, msisdn):
        """Sets the msisdn of this DiscoveryRequestV3.

        Mobile number in the international dialing format either 31600000000, +31600000000 or 0031600000000  # noqa: E501

        :param msisdn: The msisdn of this DiscoveryRequestV3.  # noqa: E501
        :type: str
        """
        if msisdn is None:
            raise ValueError("Invalid value for `msisdn`, must not be `None`")  # noqa: E501

        self._msisdn = msisdn

    @property
    def correlation_id(self):
        """Gets the correlation_id of this DiscoveryRequestV3.  # noqa: E501

        Correlates a transaction across Mobile Connect components. The value is generated by the Service Provider and must be locally unique.  This parameter should be used in conjunction with your operator partner and only for tracing and resolving issues. The recommended format is UUID4.  # noqa: E501

        :return: The correlation_id of this DiscoveryRequestV3.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this DiscoveryRequestV3.

        Correlates a transaction across Mobile Connect components. The value is generated by the Service Provider and must be locally unique.  This parameter should be used in conjunction with your operator partner and only for tracing and resolving issues. The recommended format is UUID4.  # noqa: E501

        :param correlation_id: The correlation_id of this DiscoveryRequestV3.  # noqa: E501
        :type: str
        """

        self._correlation_id = correlation_id

    @property
    def correlationId(self):
        return self.correlation_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        return {
            'correlationId': self.correlation_id,
            'msisdn': self.msisdn
        }

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiscoveryRequestV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import logging
import sys


class Config:
    def __init__(self, base_uri, consumer_name, private_key_file=None, hmac_secret=None, private_key_mem=None,
                 shared_key=None):
        assert private_key_file or private_key_mem, "either private_key_file or private_key_mem should be present"
        assert hmac_secret or shared_key, "either hmac_secret or shared_key should be present"
        self._base_uri = base_uri
        self._consumer_name = consumer_name
        self._private_key_file = private_key_file
        self._hmac_secret = hmac_secret
        self._private_key_mem = private_key_mem
        self._shared_key = shared_key

    @property
    def base_uri(self):
        return self._base_uri

    @property
    def consumer_name(self):
        return self._consumer_name

    @property
    def private_key_file(self):
        return self._private_key_file

    @property
    def hmac_secret(self):
        return self._hmac_secret

    @property
    def shared_key(self):
        return self._shared_key

    @property
    def private_key_mem(self):
        return self._private_key_mem


_format = '%(asctime)s - %(name)-8s - %(levelname)s - %(message)s'


def set_logging(format=_format, level=logging.ERROR, stream=sys.stdout):
    logging.basicConfig(format=format, level=level, stream=stream)



# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TariffInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'peak': 'str',
        'offpeak': 'str',
        'currency': 'str',
        'type': 'str',
        'vat': 'str'
    }

    attribute_map = {
        'peak': 'peak',
        'offpeak': 'offpeak',
        'currency': 'currency',
        'type': 'type',
        'vat': 'vat'
    }

    def __init__(self, peak=None, offpeak=None, currency=None, type=None, vat=None):
        """TariffInfo - a model defined in Swagger"""
        self._peak = None
        self._offpeak = None
        self._currency = None
        self._type = None
        self._vat = None
        self.discriminator = None
        self.peak = peak
        self.offpeak = offpeak
        self.currency = currency
        self.type = type
        self.vat = vat

    @property
    def peak(self):
        """Gets the peak of this TariffInfo.


        :return: The peak of this TariffInfo.
        :rtype: str
        """
        return self._peak

    @peak.setter
    def peak(self, peak):
        """Sets the peak of this TariffInfo.


        :param peak: The peak of this TariffInfo.
        :type: str
        """
        if peak is None:
            raise ValueError("Invalid value for `peak`, must not be `None`")
        if peak is not None and not re.search('^[,0-9]{7,8}$', peak):
            raise ValueError("Invalid value for `peak`, must be a follow pattern or equal to `/^[,0-9]{7,8}$/`")

        self._peak = peak

    @property
    def offpeak(self):
        """Gets the offpeak of this TariffInfo.


        :return: The offpeak of this TariffInfo.
        :rtype: str
        """
        return self._offpeak

    @offpeak.setter
    def offpeak(self, offpeak):
        """Sets the offpeak of this TariffInfo.


        :param offpeak: The offpeak of this TariffInfo.
        :type: str
        """
        if offpeak is None:
            raise ValueError("Invalid value for `offpeak`, must not be `None`")
        if offpeak is not None and not re.search('^[,0-9]{7,8}$', offpeak):
            raise ValueError("Invalid value for `offpeak`, must be a follow pattern or equal to `/^[,0-9]{7,8}$/`")

        self._offpeak = offpeak

    @property
    def currency(self):
        """Gets the currency of this TariffInfo.


        :return: The currency of this TariffInfo.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this TariffInfo.


        :param currency: The currency of this TariffInfo.
        :type: str
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")
        allowed_values = ["0", "1"]
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def type(self):
        """Gets the type of this TariffInfo.


        :return: The type of this TariffInfo.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TariffInfo.


        :param type: The type of this TariffInfo.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def vat(self):
        """Gets the vat of this TariffInfo.


        :return: The vat of this TariffInfo.
        :rtype: str
        """
        return self._vat

    @vat.setter
    def vat(self, vat):
        """Sets the vat of this TariffInfo.


        :param vat: The vat of this TariffInfo.
        :type: str
        """
        if vat is None:
            raise ValueError("Invalid value for `vat`, must not be `None`")

        self._vat = vat

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TariffInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TariffInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import HeaderCreator, NumberSeries
from coin_sdk.number_portability.messages.message import Message
from .deactivation_service_number import DeactivationServiceNumber
from .deactivation_service_number_seq import DeactivationServiceNumberSeq
from .deactivation_service_number_repeats import  DeactivationServiceNumberRepeats
from .deactivation_service_number_body import DeactivationServiceNumberBody
from .deactivation_service_number_message import  DeactivationServiceNumberMessage
from ..tariffchangeservicenumber.tariff_info import TariffInfo


class DeactivationServiceNumberBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._platformprovider = None
        self._planneddatetime = None
        self._dossierid = None
        self._note = None
        self._deactivationServiceNumber_seqs = []

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_platformprovider(self, platformprovider: str):
        self._platformprovider = platformprovider
        return self

    def set_planneddatetime(self, planneddatetime: str):
        self._planneddatetime = planneddatetime
        return self

    def add_deactivationServiceNumber_seq(self):
        return DeactivationServiceNumberRepeatsBuilder(self)

    def build(self):
        repeats = [DeactivationServiceNumberRepeats(seq) for seq in self._deactivationServiceNumber_seqs]
        deactivationServiceNumber = DeactivationServiceNumber(
            self._dossierid,
            self._platformprovider,
            self._planneddatetime,
            repeats
        )
        body = DeactivationServiceNumberBody(deactivationServiceNumber)
        message = DeactivationServiceNumberMessage(self._header, body)
        return Message(message, MessageType.DEACTIVATION_SERVICE_NUMBER_V3)


class DeactivationServiceNumberRepeatsBuilder():
    def __init__(self, deactivationServiceNumber_builder: DeactivationServiceNumberBuilder):
        super().__init__()
        self._deactivationServiceNumber_builder = deactivationServiceNumber_builder
        self._pop = None
        self._number_series = None
        self._tariff_info = None

    def set_number_series(self, start: str, end: str):
        self._number_series = NumberSeries(start, end)
        return self

    def set_pop(self, pop: str):
        self._pop = pop
        return self

    def finish(self):
        seq = DeactivationServiceNumberSeq(self._number_series, self._pop)
        self._deactivationServiceNumber_builder._deactivationServiceNumber_seqs.append(seq)
        return self._deactivationServiceNumber_builder



# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
import re

from six import iteritems


class EnumProfileActivation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dossierid': 'str',
        'currentnetworkoperator': 'str',
        'typeofnumber': 'str',
        'scope': 'str',
        'profileid': 'str',
        'ttl': 'str',
        'dnsclass': 'str',
        'rectype': 'str',
        'order': 'str',
        'preference': 'str',
        'flags': 'str',
        'enumservice': 'str',
        'regexp': 'str',
        'usertag': 'str',
        'domain': 'str',
        'spcode': 'str',
        'processtype': 'str',
        'gateway': 'str',
        'service': 'str',
        'domaintag': 'str',
        'replacement': 'str'
    }

    attribute_map = {
        'dossierid': 'dossierid',
        'currentnetworkoperator': 'currentnetworkoperator',
        'typeofnumber': 'typeofnumber',
        'scope': 'scope',
        'profileid': 'profileid',
        'ttl': 'ttl',
        'dnsclass': 'dnsclass',
        'rectype': 'rectype',
        'order': 'order',
        'preference': 'preference',
        'flags': 'flags',
        'enumservice': 'enumservice',
        'regexp': 'regexp',
        'usertag': 'usertag',
        'domain': 'domain',
        'spcode': 'spcode',
        'processtype': 'processtype',
        'gateway': 'gateway',
        'service': 'service',
        'domaintag': 'domaintag',
        'replacement': 'replacement'
    }

    def __init__(self, dossierid=None, currentnetworkoperator=None, typeofnumber=None, scope=None, profileid=None, ttl=None, dnsclass=None, rectype=None, order=None, preference=None, flags=None, enumservice=None, regexp=None, usertag=None, domain=None, spcode=None, processtype=None, gateway=None, service=None, domaintag=None, replacement=None):
        """EnumProfileActivation - a model defined in Swagger"""
        self._dossierid = None
        self._currentnetworkoperator = None
        self._typeofnumber = None
        self._scope = None
        self._profileid = None
        self._ttl = None
        self._dnsclass = None
        self._rectype = None
        self._order = None
        self._preference = None
        self._flags = None
        self._enumservice = None
        self._regexp = None
        self._usertag = None
        self._domain = None
        self._spcode = None
        self._processtype = None
        self._gateway = None
        self._service = None
        self._domaintag = None
        self._replacement = None
        self.discriminator = None
        self.dossierid = dossierid
        self.currentnetworkoperator = currentnetworkoperator
        self.typeofnumber = typeofnumber
        self.scope = scope
        self.profileid = profileid
        self.ttl = ttl
        self.dnsclass = dnsclass
        self.rectype = rectype
        if order is not None:
            self.order = order
        if preference is not None:
            self.preference = preference
        if flags is not None:
            self.flags = flags
        if enumservice is not None:
            self.enumservice = enumservice
        if regexp is not None:
            self.regexp = regexp
        if usertag is not None:
            self.usertag = usertag
        if domain is not None:
            self.domain = domain
        if spcode is not None:
            self.spcode = spcode
        if processtype is not None:
            self.processtype = processtype
        if gateway is not None:
            self.gateway = gateway
        if service is not None:
            self.service = service
        if domaintag is not None:
            self.domaintag = domaintag
        if replacement is not None:
            self.replacement = replacement

    @property
    def dossierid(self):
        """Gets the dossierid of this EnumProfileActivation.


        :return: The dossierid of this EnumProfileActivation.
        :rtype: str
        """
        return self._dossierid

    @dossierid.setter
    def dossierid(self, dossierid):
        """Sets the dossierid of this EnumProfileActivation.


        :param dossierid: The dossierid of this EnumProfileActivation.
        :type: str
        """
        if dossierid is None:
            raise ValueError("Invalid value for `dossierid`, must not be `None`")
        if dossierid is not None and not re.search('^[-0-9A-Z]{5,26}$', dossierid):
            raise ValueError("Invalid value for `dossierid`, must be a follow pattern or equal to `/^[-0-9A-Z]{5,26}$/`")

        self._dossierid = dossierid

    @property
    def currentnetworkoperator(self):
        """Gets the currentnetworkoperator of this EnumProfileActivation.


        :return: The currentnetworkoperator of this EnumProfileActivation.
        :rtype: str
        """
        return self._currentnetworkoperator

    @currentnetworkoperator.setter
    def currentnetworkoperator(self, currentnetworkoperator):
        """Sets the currentnetworkoperator of this EnumProfileActivation.


        :param currentnetworkoperator: The currentnetworkoperator of this EnumProfileActivation.
        :type: str
        """
        if currentnetworkoperator is None:
            raise ValueError("Invalid value for `currentnetworkoperator`, must not be `None`")
        if currentnetworkoperator is not None and not re.search('^[0-9A-Z]{3,6}$', currentnetworkoperator):
            raise ValueError("Invalid value for `currentnetworkoperator`, must be a follow pattern or equal to `/^[0-9A-Z]{3,6}$/`")

        self._currentnetworkoperator = currentnetworkoperator

    @property
    def typeofnumber(self):
        """Gets the typeofnumber of this EnumProfileActivation.


        :return: The typeofnumber of this EnumProfileActivation.
        :rtype: str
        """
        return self._typeofnumber

    @typeofnumber.setter
    def typeofnumber(self, typeofnumber):
        """Sets the typeofnumber of this EnumProfileActivation.


        :param typeofnumber: The typeofnumber of this EnumProfileActivation.
        :type: str
        """
        if typeofnumber is None:
            raise ValueError("Invalid value for `typeofnumber`, must not be `None`")

        self._typeofnumber = typeofnumber

    @property
    def scope(self):
        """Gets the scope of this EnumProfileActivation.


        :return: The scope of this EnumProfileActivation.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this EnumProfileActivation.


        :param scope: The scope of this EnumProfileActivation.
        :type: str
        """
        if scope is None:
            raise ValueError("Invalid value for `scope`, must not be `None`")
        if scope is not None and not re.search('^[-0-9A-Z]{1,40}$', scope):
            raise ValueError("Invalid value for `scope`, must be a follow pattern or equal to `/^[-0-9A-Z]{1,40}$/`")

        self._scope = scope

    @property
    def profileid(self):
        """Gets the profileid of this EnumProfileActivation.


        :return: The profileid of this EnumProfileActivation.
        :rtype: str
        """
        return self._profileid

    @profileid.setter
    def profileid(self, profileid):
        """Sets the profileid of this EnumProfileActivation.


        :param profileid: The profileid of this EnumProfileActivation.
        :type: str
        """
        if profileid is None:
            raise ValueError("Invalid value for `profileid`, must not be `None`")
        if profileid is not None and not re.search('^[-0-9A-Z]{5,26}$', profileid):
            raise ValueError("Invalid value for `profileid`, must be a follow pattern or equal to `/^[-0-9A-Z]{5,26}$/`")

        self._profileid = profileid

    @property
    def ttl(self):
        """Gets the ttl of this EnumProfileActivation.


        :return: The ttl of this EnumProfileActivation.
        :rtype: str
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this EnumProfileActivation.


        :param ttl: The ttl of this EnumProfileActivation.
        :type: str
        """
        if ttl is None:
            raise ValueError("Invalid value for `ttl`, must not be `None`")

        self._ttl = ttl

    @property
    def dnsclass(self):
        """Gets the dnsclass of this EnumProfileActivation.


        :return: The dnsclass of this EnumProfileActivation.
        :rtype: str
        """
        return self._dnsclass

    @dnsclass.setter
    def dnsclass(self, dnsclass):
        """Sets the dnsclass of this EnumProfileActivation.


        :param dnsclass: The dnsclass of this EnumProfileActivation.
        :type: str
        """
        if dnsclass is None:
            raise ValueError("Invalid value for `dnsclass`, must not be `None`")
        if dnsclass is not None and len(dnsclass) > 40:
            raise ValueError("Invalid value for `dnsclass`, length must be less than or equal to `40`")
        if dnsclass is not None and len(dnsclass) < 1:
            raise ValueError("Invalid value for `dnsclass`, length must be greater than or equal to `1`")

        self._dnsclass = dnsclass

    @property
    def rectype(self):
        """Gets the rectype of this EnumProfileActivation.


        :return: The rectype of this EnumProfileActivation.
        :rtype: str
        """
        return self._rectype

    @rectype.setter
    def rectype(self, rectype):
        """Sets the rectype of this EnumProfileActivation.


        :param rectype: The rectype of this EnumProfileActivation.
        :type: str
        """
        if rectype is None:
            raise ValueError("Invalid value for `rectype`, must not be `None`")
        if rectype is not None and len(rectype) > 40:
            raise ValueError("Invalid value for `rectype`, length must be less than or equal to `40`")
        if rectype is not None and len(rectype) < 1:
            raise ValueError("Invalid value for `rectype`, length must be greater than or equal to `1`")

        self._rectype = rectype

    @property
    def order(self):
        """Gets the order of this EnumProfileActivation.


        :return: The order of this EnumProfileActivation.
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this EnumProfileActivation.


        :param order: The order of this EnumProfileActivation.
        :type: str
        """

        self._order = order

    @property
    def preference(self):
        """Gets the preference of this EnumProfileActivation.


        :return: The preference of this EnumProfileActivation.
        :rtype: str
        """
        return self._preference

    @preference.setter
    def preference(self, preference):
        """Sets the preference of this EnumProfileActivation.


        :param preference: The preference of this EnumProfileActivation.
        :type: str
        """

        self._preference = preference

    @property
    def flags(self):
        """Gets the flags of this EnumProfileActivation.


        :return: The flags of this EnumProfileActivation.
        :rtype: str
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this EnumProfileActivation.


        :param flags: The flags of this EnumProfileActivation.
        :type: str
        """
        if flags is not None and len(flags) > 40:
            raise ValueError("Invalid value for `flags`, length must be less than or equal to `40`")
        if flags is not None and len(flags) < 1:
            raise ValueError("Invalid value for `flags`, length must be greater than or equal to `1`")

        self._flags = flags

    @property
    def enumservice(self):
        """Gets the enumservice of this EnumProfileActivation.


        :return: The enumservice of this EnumProfileActivation.
        :rtype: str
        """
        return self._enumservice

    @enumservice.setter
    def enumservice(self, enumservice):
        """Sets the enumservice of this EnumProfileActivation.


        :param enumservice: The enumservice of this EnumProfileActivation.
        :type: str
        """
        if enumservice is not None and len(enumservice) > 65:
            raise ValueError("Invalid value for `enumservice`, length must be less than or equal to `65`")
        if enumservice is not None and len(enumservice) < 1:
            raise ValueError("Invalid value for `enumservice`, length must be greater than or equal to `1`")

        self._enumservice = enumservice

    @property
    def regexp(self):
        """Gets the regexp of this EnumProfileActivation.


        :return: The regexp of this EnumProfileActivation.
        :rtype: str
        """
        return self._regexp

    @regexp.setter
    def regexp(self, regexp):
        """Sets the regexp of this EnumProfileActivation.


        :param regexp: The regexp of this EnumProfileActivation.
        :type: str
        """
        if regexp is not None and len(regexp) > 400:
            raise ValueError("Invalid value for `regexp`, length must be less than or equal to `400`")
        if regexp is not None and len(regexp) < 1:
            raise ValueError("Invalid value for `regexp`, length must be greater than or equal to `1`")

        self._regexp = regexp

    @property
    def usertag(self):
        """Gets the usertag of this EnumProfileActivation.


        :return: The usertag of this EnumProfileActivation.
        :rtype: str
        """
        return self._usertag

    @usertag.setter
    def usertag(self, usertag):
        """Sets the usertag of this EnumProfileActivation.


        :param usertag: The usertag of this EnumProfileActivation.
        :type: str
        """
        if usertag is not None and len(usertag) > 400:
            raise ValueError("Invalid value for `usertag`, length must be less than or equal to `400`")
        if usertag is not None and len(usertag) < 1:
            raise ValueError("Invalid value for `usertag`, length must be greater than or equal to `1`")

        self._usertag = usertag

    @property
    def domain(self):
        """Gets the domain of this EnumProfileActivation.


        :return: The domain of this EnumProfileActivation.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this EnumProfileActivation.


        :param domain: The domain of this EnumProfileActivation.
        :type: str
        """
        if domain is not None and len(domain) > 255:
            raise ValueError("Invalid value for `domain`, length must be less than or equal to `255`")
        if domain is not None and len(domain) < 1:
            raise ValueError("Invalid value for `domain`, length must be greater than or equal to `1`")

        self._domain = domain

    @property
    def spcode(self):
        """Gets the spcode of this EnumProfileActivation.


        :return: The spcode of this EnumProfileActivation.
        :rtype: str
        """
        return self._spcode

    @spcode.setter
    def spcode(self, spcode):
        """Sets the spcode of this EnumProfileActivation.


        :param spcode: The spcode of this EnumProfileActivation.
        :type: str
        """
        if spcode is not None and len(spcode) > 40:
            raise ValueError("Invalid value for `spcode`, length must be less than or equal to `40`")
        if spcode is not None and len(spcode) < 1:
            raise ValueError("Invalid value for `spcode`, length must be greater than or equal to `1`")

        self._spcode = spcode

    @property
    def processtype(self):
        """Gets the processtype of this EnumProfileActivation.


        :return: The processtype of this EnumProfileActivation.
        :rtype: str
        """
        return self._processtype

    @processtype.setter
    def processtype(self, processtype):
        """Sets the processtype of this EnumProfileActivation.


        :param processtype: The processtype of this EnumProfileActivation.
        :type: str
        """
        if processtype is not None and len(processtype) > 40:
            raise ValueError("Invalid value for `processtype`, length must be less than or equal to `40`")
        if processtype is not None and len(processtype) < 1:
            raise ValueError("Invalid value for `processtype`, length must be greater than or equal to `1`")

        self._processtype = processtype

    @property
    def gateway(self):
        """Gets the gateway of this EnumProfileActivation.


        :return: The gateway of this EnumProfileActivation.
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this EnumProfileActivation.


        :param gateway: The gateway of this EnumProfileActivation.
        :type: str
        """
        if gateway is not None and len(gateway) > 40:
            raise ValueError("Invalid value for `gateway`, length must be less than or equal to `40`")
        if gateway is not None and len(gateway) < 1:
            raise ValueError("Invalid value for `gateway`, length must be greater than or equal to `1`")

        self._gateway = gateway

    @property
    def service(self):
        """Gets the service of this EnumProfileActivation.


        :return: The service of this EnumProfileActivation.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this EnumProfileActivation.


        :param service: The service of this EnumProfileActivation.
        :type: str
        """
        if service is not None and len(service) > 400:
            raise ValueError("Invalid value for `service`, length must be less than or equal to `400`")
        if service is not None and len(service) < 1:
            raise ValueError("Invalid value for `service`, length must be greater than or equal to `1`")

        self._service = service

    @property
    def domaintag(self):
        """Gets the domaintag of this EnumProfileActivation.


        :return: The domaintag of this EnumProfileActivation.
        :rtype: str
        """
        return self._domaintag

    @domaintag.setter
    def domaintag(self, domaintag):
        """Sets the domaintag of this EnumProfileActivation.


        :param domaintag: The domaintag of this EnumProfileActivation.
        :type: str
        """
        if domaintag is not None and len(domaintag) > 400:
            raise ValueError("Invalid value for `domaintag`, length must be less than or equal to `400`")
        if domaintag is not None and len(domaintag) < 1:
            raise ValueError("Invalid value for `domaintag`, length must be greater than or equal to `1`")

        self._domaintag = domaintag

    @property
    def replacement(self):
        """Gets the replacement of this EnumProfileActivation.


        :return: The replacement of this EnumProfileActivation.
        :rtype: str
        """
        return self._replacement

    @replacement.setter
    def replacement(self, replacement):
        """Sets the replacement of this EnumProfileActivation.


        :param replacement: The replacement of this EnumProfileActivation.
        :type: str
        """
        if replacement is not None and len(replacement) > 400:
            raise ValueError("Invalid value for `replacement`, length must be less than or equal to `400`")
        if replacement is not None and len(replacement) < 1:
            raise ValueError("Invalid value for `replacement`, length must be greater than or equal to `1`")

        self._replacement = replacement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnumProfileActivation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnumProfileActivation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    COIN Mobile Connect Rest API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 3
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from coin_sdk.mobile_connect.v3.domain.supported_services import SupportedServicesDto


class DiscoveryResponseV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'network_operator_code': 'str',
        'supported_services': 'SupportedServicesDto',
        'correlation_id': 'str',
        'client_id': 'str',
        'client_secret': 'str'
    }

    attribute_map = {
        'network_operator_code': 'networkOperatorCode',
        'supported_services': 'supportedServices',
        'correlation_id': 'correlationId',
        'client_id': 'clientId',
        'client_secret': 'clientSecret'
    }

    def __init__(
            self,
            networkOperatorCode: str = None,
            supportedServices: SupportedServicesDto = None,
            correlationId: str = None,
            clientId: str = None,
            clientSecret: str = None
    ):  # noqa: E501
        """DiscoveryResponseV3 - a model defined in Swagger"""  # noqa: E501
        self._network_operator_code = None
        self._supported_services = None
        self._correlation_id = None
        self._client_id = None
        self._client_secret = None
        self.discriminator = None
        self.network_operator_code = networkOperatorCode
        self.supported_services = supportedServices
        if correlationId is not None:
            self.correlation_id = correlationId
        if clientId is not None:
            self.client_id = clientId
        if clientSecret is not None:
            self.client_secret = clientSecret

    @property
    def network_operator_code(self):
        """Gets the network_operator_code of this DiscoveryResponseV3.  # noqa: E501


        :return: The network_operator_code of this DiscoveryResponseV3.  # noqa: E501
        :rtype: str
        """
        return self._network_operator_code

    @network_operator_code.setter
    def network_operator_code(self, network_operator_code):
        """Sets the network_operator_code of this DiscoveryResponseV3.


        :param network_operator_code: The network_operator_code of this DiscoveryResponseV3.  # noqa: E501
        :type: str
        """
        if network_operator_code is None:
            raise ValueError("Invalid value for `network_operator_code`, must not be `None`")  # noqa: E501

        self._network_operator_code = network_operator_code

    @property
    def supported_services(self):
        """Gets the supported_services of this DiscoveryResponseV3.  # noqa: E501


        :return: The supported_services of this DiscoveryResponseV3.  # noqa: E501
        :rtype: SupportedServicesDto
        """
        return self._supported_services

    @supported_services.setter
    def supported_services(self, supported_services):
        """Sets the supported_services of this DiscoveryResponseV3.


        :param supported_services: The supported_services of this DiscoveryResponseV3.  # noqa: E501
        :type: SupportedServicesDto
        """
        if supported_services is None:
            raise ValueError("Invalid value for `supported_services`, must not be `None`")  # noqa: E501

        self._supported_services = supported_services

    @property
    def correlation_id(self):
        """Gets the correlation_id of this DiscoveryResponseV3.  # noqa: E501

        Correlates a transaction across Mobile Connect components. The value is generated by the Service Provider and must be locally unique.  This parameter should be used in conjunction with your operator partner and only for tracing and resolving issues. The recommended format is UUID4.  # noqa: E501

        :return: The correlation_id of this DiscoveryResponseV3.  # noqa: E501
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """Sets the correlation_id of this DiscoveryResponseV3.

        Correlates a transaction across Mobile Connect components. The value is generated by the Service Provider and must be locally unique.  This parameter should be used in conjunction with your operator partner and only for tracing and resolving issues. The recommended format is UUID4.  # noqa: E501

        :param correlation_id: The correlation_id of this DiscoveryResponseV3.  # noqa: E501
        :type: str
        """

        self._correlation_id = correlation_id

    @property
    def client_id(self):
        """Gets the client_id of this DiscoveryResponseV3.  # noqa: E501

        Operator specific Client ID to be used by OIDC requests to the operator ID Gateway.  # noqa: E501

        :return: The client_id of this DiscoveryResponseV3.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this DiscoveryResponseV3.

        Operator specific Client ID to be used by OIDC requests to the operator ID Gateway.  # noqa: E501

        :param client_id: The client_id of this DiscoveryResponseV3.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this DiscoveryResponseV3.  # noqa: E501

        Operator specific Client Secret to be used by OIDC requests to the operator ID Gateway.  # noqa: E501

        :return: The client_secret of this DiscoveryResponseV3.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this DiscoveryResponseV3.

        Operator specific Client Secret to be used by OIDC requests to the operator ID Gateway.  # noqa: E501

        :param client_secret: The client_secret of this DiscoveryResponseV3.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DiscoveryResponseV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiscoveryResponseV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import re
from pprint import pformat

from six import iteritems


class DeactivationServiceNumber(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dossierid': 'str',
        'platformprovider': 'str',
        'planneddatetime': 'str',
        'repeats': 'list[DeactivationServiceNumberRepeats]'
    }

    attribute_map = {
        'dossierid': 'dossierid',
        'platformprovider': 'platformprovider',
        'planneddatetime': 'planneddatetime',
        'repeats': 'repeats'
    }

    def __init__(self, dossierid=None, platformprovider=None, planneddatetime=None, repeats=None):
        """DeactivationServiceNumber - a model defined in Swagger"""
        self._dossierid = None
        self._platformprovider = None
        self._planneddatetime = None
        self._repeats = None
        self.discriminator = None
        self.dossierid = dossierid
        self.platformprovider = platformprovider
        self.planneddatetime = planneddatetime
        self.repeats = repeats

    @property
    def dossierid(self):
        """Gets the dossierid of this DeactivationServiceNumber.


        :return: The dossierid of this DeactivationServiceNumber.
        :rtype: str
        """
        return self._dossierid

    @dossierid.setter
    def dossierid(self, dossierid):
        """Sets the dossierid of this DeactivationServiceNumber.


        :param dossierid: The dossierid of this DeactivationServiceNumber.
        :type: str
        """
        if dossierid is None:
            raise ValueError("Invalid value for `dossierid`, must not be `None`")
        if dossierid is not None and not re.search('^[-0-9A-Z]{5,26}$', dossierid):
            raise ValueError("Invalid value for `dossierid`, must be a follow pattern or equal to `/^[-0-9A-Z]{5,26}$/`")

        self._dossierid = dossierid

    @property
    def platformprovider(self):
        """Gets the platformprovider of this DeactivationServiceNumber.


        :return: The platformprovider of this DeactivationServiceNumber.
        :rtype: str
        """
        return self._platformprovider

    @platformprovider.setter
    def platformprovider(self, platformprovider):
        """Sets the platformprovider of this DeactivationServiceNumber.


        :param platformprovider: The platformprovider of this DeactivationServiceNumber.
        :type: str
        """
        if platformprovider is None:
            raise ValueError("Invalid value for `platformprovider`, must not be `None`")
        if platformprovider is not None and not re.search('^[0-9A-Z]{3,6}$', platformprovider):
            raise ValueError("Invalid value for `platformprovider`, must be a follow pattern or equal to `/^[0-9A-Z]{3,6}$/`")

        self._platformprovider = platformprovider

    @property
    def planneddatetime(self):
        """Gets the planneddatetime of this DeactivationServiceNumber.


        :return: The planneddatetime of this DeactivationServiceNumber.
        :rtype: str
        """
        return self._planneddatetime

    @planneddatetime.setter
    def planneddatetime(self, planneddatetime):
        """Sets the planneddatetime of this DeactivationServiceNumber.


        :param planneddatetime: The planneddatetime of this DeactivationServiceNumber.
        :type: str
        """
        if planneddatetime is None:
            raise ValueError("Invalid value for `planneddatetime`, must not be `None`")
        if planneddatetime is not None and not re.search('^[0-9]{14}$', planneddatetime):
            raise ValueError("Invalid value for `planneddatetime`, must be a follow pattern or equal to `/^[0-9]{14}$/`")

        self._planneddatetime = planneddatetime

    @property
    def repeats(self):
        """Gets the repeats of this DeactivationServiceNumber.


        :return: The repeats of this DeactivationServiceNumber.
        :rtype: list[DeactivationServiceNumberRepeats]
        """
        return self._repeats

    @repeats.setter
    def repeats(self, repeats):
        """Sets the repeats of this DeactivationServiceNumber.


        :param repeats: The repeats of this DeactivationServiceNumber.
        :type: list[DeactivationServiceNumberRepeats]
        """
        if repeats is None:
            raise ValueError("Invalid value for `repeats`, must not be `None`")

        self._repeats = repeats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeactivationServiceNumber, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeactivationServiceNumber):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import CustomerInfo, EnumRepeatsBuilder, HeaderCreator
from coin_sdk.number_portability.messages.enum.enum_content import EnumContent
from coin_sdk.number_portability.messages.message import Message
from .enum_deactivation_range_body import EnumDeactivationRangeBody
from .enum_deactivation_range_message import EnumDeactivationRangeMessage
from .enum_number_repeats import EnumNumberRepeats
from .enum_number_seq import EnumNumberSeq


class EnumDeactivationRangeBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._dossierid = None
        self._currentnetworkoperator = None
        self._typeofnumber = None
        self._enum_deactivation_range_seqs = []

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_currentnetworkoperator(self, currentnetworkoperator: str):
        self._currentnetworkoperator = currentnetworkoperator
        return self

    def set_typeofnumber(self, typeofnumber: str):
        self._typeofnumber = typeofnumber
        return self

    def add_enum_deactivation_range_seq(self):
        return EnumDeactivationRangeRepeatsBuilder(self)

    def build(self):
        repeats = [EnumNumberRepeats(seq) for seq in self._enum_deactivation_range_seqs]
        enum_deactivation_range = EnumContent(
            self._dossierid,
            self._currentnetworkoperator,
            self._typeofnumber,
            repeats
        )
        body = EnumDeactivationRangeBody(enum_deactivation_range)
        message = EnumDeactivationRangeMessage(self._header, body)
        return Message(message, MessageType.ENUM_DEACTIVATION_RANGE_V3)


class EnumDeactivationRangeRepeatsBuilder(EnumRepeatsBuilder):
    def __init__(self, enum_deactivation_range_builder: EnumDeactivationRangeBuilder):
        super().__init__()
        self._enum_deactivation_range_builder = enum_deactivation_range_builder

    def set_number_series(self, start: str, end: str):
        self._set_number_series(start, end)
        return self

    def add_enum_profiles(self, *profileids):
        self._add_enum_prof_seq(*profileids)
        return self

    def finish(self):
        seq = EnumNumberSeq(self._number_series, self._enum_repeats)
        self._enum_deactivation_range_builder._enum_deactivation_range_seqs.append(seq)
        return self._enum_deactivation_range_builder



from .enum_activation_number_builder import EnumActivationNumberBuilder
from .enum_deactivation_number_builder import EnumDeactivationNumberBuilder
from .enum_activation_operator_builder import EnumActivationOperatorBuilder
from .enum_deactivation_operator_builder import EnumDeactivationOperatorBuilder
from .enum_activation_range_builder import EnumActivationRangeBuilder
from .enum_deactivation_range_builder import EnumDeactivationRangeBuilder
from .enum_profile_activation_builder import EnumProfileActivationBuilder
from .enum_profile_deactivation_builder import EnumProfileDeactivationBuilder



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import HeaderCreator, NumberSeries
from coin_sdk.number_portability.messages.message import Message
from .activation_service_number import ActivationServiceNumber
from .activation_service_number_seq import ActivationServiceNumberSeq
from .activation_service_number_repeats import  ActivationServiceNumberRepeats
from .activation_service_number_body import ActivationServiceNumberBody
from .activation_service_number_message import  ActivationServiceNumberMessage
from ..tariffchangeservicenumber.tariff_info import TariffInfo


class ActivationServiceNumberBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._platformprovider = None
        self._planneddatetime = None
        self._dossierid = None
        self._note = None
        self._activationServiceNumber_seqs = []

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_platformprovider(self, platformprovider: str):
        self._platformprovider = platformprovider
        return self

    def set_planneddatetime(self, planneddatetime: str):
        self._planneddatetime = planneddatetime
        return self

    def set_note(self, note: str):
        self._note = note
        return self

    def add_activationServiceNumber_seq(self):
        return ActivationServiceNumberRepeatsBuilder(self)

    def build(self):
        repeats = [ActivationServiceNumberRepeats(seq) for seq in self._activationServiceNumber_seqs]
        activationServiceNumber = ActivationServiceNumber(
            self._dossierid,
            self._platformprovider,
            self._planneddatetime,
            self._note,
            repeats
        )
        body = ActivationServiceNumberBody(activationServiceNumber)
        message = ActivationServiceNumberMessage(self._header, body)
        return Message(message, MessageType.ACTIVATION_SERVICE_NUMBER_V3)


class ActivationServiceNumberRepeatsBuilder():
    def __init__(self, activationServiceNumber_builder: ActivationServiceNumberBuilder):
        super().__init__()
        self._activationServiceNumber_builder = activationServiceNumber_builder
        self._pop = None
        self._number_series = None
        self._tariff_info = None

    def set_number_series(self, start: str, end: str):
        self._number_series = NumberSeries(start, end)
        return self

    def set_pop(self, pop: str):
        self._pop = pop
        return self

    def set_tariff_info(self, peak: str, offPeak: str, currency: str, type: str, vat: str):
        tariffInfo = TariffInfo(peak, offPeak, currency, type, vat)
        self._tariff_info = tariffInfo
        return self

    def finish(self):
        seq = ActivationServiceNumberSeq(self._number_series, self._tariff_info, self._pop)
        self._activationServiceNumber_builder._activationServiceNumber_seqs.append(seq)
        return self._activationServiceNumber_builder



# coding: utf-8

"""
    COIN Number Portability API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 3.0.0
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re

import six


class Cancel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dossierid': 'str',
        'note': 'str'
    }

    attribute_map = {
        'dossierid': 'dossierid',
        'note': 'note'
    }

    def __init__(self, dossierid=None, note=None):
        """Cancel - a model defined in Swagger"""
        self._dossierid = None
        self._note = None
        self.discriminator = None
        self.dossierid = dossierid
        if note is not None:
            self.note = note

    @property
    def dossierid(self):
        """Gets the dossierid of this Cancel.


        :return: The dossierid of this Cancel.
        :rtype: str
        """
        return self._dossierid

    @dossierid.setter
    def dossierid(self, dossierid):
        """Sets the dossierid of this Cancel.


        :param dossierid: The dossierid of this Cancel.
        :type: str
        """
        if dossierid is None:
            raise ValueError("Invalid value for `dossierid`, must not be `None`")  # noqa: E501
        if dossierid is not None and not re.search(r'[-0-9A-Z]{5,26}', dossierid):  # noqa: E501
            raise ValueError(r"Invalid value for `dossierid`, must be a follow pattern or equal to `/[-0-9A-Z]{5,26}/`")  # noqa: E501

        self._dossierid = dossierid

    @property
    def note(self):
        """Gets the note of this Cancel.


        :return: The note of this Cancel.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this Cancel.


        :param note: The note of this Cancel.
        :type: str
        """
        if note is not None and len(note) > 100:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `100`")  # noqa: E501
        if note is not None and len(note) < 1:
            raise ValueError("Invalid value for `note`, length must be greater than or equal to `1`")  # noqa: E501

        self._note = note

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Cancel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cancel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import os
import random
import unittest

from requests import HTTPError

from coin_sdk.number_portability.domain import ConfirmationStatus
from coin_sdk.number_portability.messages.activationservicenumber import ActivationServiceNumberBuilder
from coin_sdk.number_portability.messages.cancel import CancelBuilder
from coin_sdk.number_portability.messages.deactivation import DeactivationBuilder
from coin_sdk.number_portability.messages.deactivationservicenumber.deactivation_service_number_builder import \
    DeactivationServiceNumberBuilder
from coin_sdk.number_portability.messages.enum import EnumActivationNumberBuilder, EnumDeactivationNumberBuilder, \
    EnumProfileActivationBuilder, EnumProfileDeactivationBuilder
from coin_sdk.number_portability.messages.enum.enum_activation_operator_builder import EnumActivationOperatorBuilder
from coin_sdk.number_portability.messages.enum.enum_deactivation_operator_builder import EnumDeactivationOperatorBuilder
from coin_sdk.number_portability.messages.portingperformed import PortingPerformedBuilder
from coin_sdk.number_portability.messages.portingrequest import PortingRequestBuilder
from coin_sdk.number_portability.messages.portingrequest.porting_request_builder import ContractType
from coin_sdk.number_portability.messages.portingrequestanswer import PortingRequestAnswerBuilder
from coin_sdk.number_portability.messages.portingrequestanswerdelayed import PortingRequestAnswerDelayedBuilder
from coin_sdk.number_portability.messages.tariffchangeservicenumber.tariff_change_service_number_builder import \
    TariffChangeServiceNumberBuilder
from coin_sdk.number_portability.npconfig import NpConfig
from coin_sdk.number_portability.receiver import Receiver, OffsetPersister
from coin_sdk.number_portability.sender import Sender

config = NpConfig(
    os.getenv('CRDB_REST_BACKEND', 'http://0.0.0.0:8000'),
    'loadtest-loada',
    private_key_file='./test/setup/private-key.pem',
    hmac_secret='./test/setup/sharedkey.encrypted'
)

sender = Sender(config)


class ExamplesTest(unittest.TestCase):

    def test_porting_request(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        porting_request = (
            PortingRequestBuilder()
            .set_dossierid(dossier_id)
            .set_recipientnetworkoperator('LOADB')
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_contract(ContractType.CONTINUATION)
            .add_porting_request_seq()
                .set_number_series('0612345678', '0612345678')
                .finish()
            .add_porting_request_seq()
                .set_number_series('0612345678', '0612345678')
                .add_enum_profiles('PROF1', 'PROF2')
                .finish()
            .set_customerinfo("test", "test bv", "1", "a", "1234AB", "1")
            .build()
        )
        result = sender.send_message(porting_request)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_cancel(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        cancel = CancelBuilder() \
            .set_dossierid(dossier_id) \
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB') \
            .build()
        result = sender.send_message(cancel)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_deactivation(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        deactivation = (
            DeactivationBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_originalnetworkoperator('LOADA')
            .add_deactivation_seq()
                .set_number_series('0612345678', '0612345678')
                .finish()
            .build()
        )
        result = sender.send_message(deactivation)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_porting_performed(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        porting_performed = (
            PortingPerformedBuilder()
            .set_header('LOADA', 'LOADB')
            .set_dossierid(dossier_id)
            .set_donornetworkoperator('LOADB')
            .set_recipientnetworkoperator('LOADA')
            .add_porting_performed_seq()
                .set_number_series('0612345678', '0612345678')
                .finish()
            .add_porting_performed_seq()
                .set_number_series('0612345678', '0612345678')
                .add_enum_profiles('PROF1', 'PROF2')
                .finish()
            .build()
        )
        result = sender.send_message(porting_performed)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_porting_request_answer(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        porting_performed_answer = (
            PortingRequestAnswerBuilder()
            .set_header('LOADA', 'LOADB')
            .set_dossierid(dossier_id)
            .set_blocking('N')
            .add_porting_request_answer_seq()
                .set_donornetworkoperator('LOADA')
                .set_donorserviceprovider('LOADA')
                .set_firstpossibledate('20190101120000')
                .set_number_series('0612345678', '0612345678')
                .set_note('This is a note')
                .set_blockingcode('99')
                .finish()
            .add_porting_request_answer_seq()
                .set_donornetworkoperator('LOADA')
                .set_donorserviceprovider('LOADA')
                .set_firstpossibledate('20190101120000')
                .set_number_series('0612345678', '0612345678')
                .set_note('This is a note')
                .set_blockingcode('99')
                .finish()
            .build()
        )
        result = sender.send_message(porting_performed_answer)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_porting_request_answer_delayed(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        porting_request_answer_delayed = (
            PortingRequestAnswerDelayedBuilder()
            .set_header('LOADA', 'LOADB')
            .set_dossierid(dossier_id)
            .set_donornetworkoperator('LOADB')
            .build()
        )
        result = sender.send_message(porting_request_answer_delayed)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_send_error(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        porting_request_answer_delayed = (
            PortingRequestAnswerDelayedBuilder()
                .set_header('LOADA', 'LOADA')
                .set_dossierid(dossier_id)
                .set_donornetworkoperator('LOADB')
                .build()
        )
        try:
            sender.send_message(porting_request_answer_delayed)
        except HTTPError as e:
            print(e)

    def test_activationsn(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        activationsn = (
            ActivationServiceNumberBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_platformprovider('LOADB')
            .set_planneddatetime("20190101121212")
            .set_note("A Note")
            .add_activationServiceNumber_seq()
                .set_number_series('0612345678', '0612345678')
                .set_tariff_info("1023,00", "1023,00", "1", "2", "3")
                .set_pop("Test")
                .finish()
            .build()
        )
        result = sender.send_message(activationsn)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_deactivationsn(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        deactivationsn = (
            DeactivationServiceNumberBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_platformprovider('LOADB')
            .set_planneddatetime("20190101121212")
            .add_deactivationServiceNumber_seq()
                .set_number_series('0612345678', '0612345678')
                .set_pop("Test")
                .finish()
            .build()
        )
        result = sender.send_message(deactivationsn)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_tariffchangesn(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        tariffchangesn = (
            TariffChangeServiceNumberBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_platformprovider('LOADB')
            .set_planneddatetime("20190101121212")
            .add_tariffChangeServiceNumber_seq()
                .set_number_series('0612345678', '0612345678')
                .set_tariff_info("1023,00", "1023,00", "1", "2", "3")
                .finish()
            .build()
        )
        result = sender.send_message(tariffchangesn)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumactivationnumber(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumactivationnumber = (
            EnumActivationNumberBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("1")
            .add_enum_activation_number_seq()
                .set_number_series('0612345678', '0612345678')
                .add_enum_profiles("PROF1", "PROF2")
                .finish()
            .build()
        )
        result = sender.send_message(enumactivationnumber)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumdeactivationnumber(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumdeactivationnumber = (
            EnumDeactivationNumberBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("1")
            .add_enum_deactivation_number_seq()
                .set_number_series('0612345678', '0612345678')
                .add_enum_profiles("PROF1", "PROF2")
                .finish()
            .build()
        )
        result = sender.send_message(enumdeactivationnumber)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumactivationoperator(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumactivationoperator = (
            EnumActivationOperatorBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("1")
            .add_enum_activation_operator_seq()
                .set_profileid("PROF-12")
                .set_default_service("Y")
                .finish()
            .build()
        )
        result = sender.send_message(enumactivationoperator)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumdeactivationoperator(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumdeactivationoperator = (
            EnumDeactivationOperatorBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("1")
            .add_enum_deactivation_operator_seq()
                .set_profileid("PROF-12")
                .set_default_service("Y")
                .finish()
            .build()
        )
        result = sender.send_message(enumdeactivationoperator)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumprofileactivation(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumprofileactivation = (
            EnumProfileActivationBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("3")
            .set_scope("SCOPE-123")
            .set_profileid("5879AF-GNU9480N")
            .set_ttl("7")
            .set_dnsclass("abc def")
            .set_rectype("uvw xyz")
            .set_order("13")
            .set_preference("13")
            .set_flags("abc, def")
            .set_enumservice("Enum Service 123")
            .set_regexp("[A-Z][a-z]+\\\\d")
            .set_usertag("tag123123kjkjk")
            .set_domain("domain123")
            .set_spcode("23kjkj324")
            .set_processtype("processTypeX")
            .set_gateway("6i3k")
            .set_service("sdf sdfdsf")
            .set_domaintag("fdksalfds2132")
            .set_replacement("sdf dsjhsfd sdfsfd")
            .build()
        )
        result = sender.send_message(enumprofileactivation)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId");

    def test_enumprofiledeactivation(self):
        dossier_id = self._generate_random_dossier_id('LOADA')
        enumprofiledeactivation = (
            EnumProfileDeactivationBuilder()
            .set_header(sender_network_operator='LOADA', receiver_network_operator='LOADB')
            .set_dossierid(dossier_id)
            .set_currentnetworkoperator('LOADB')
            .set_typeofnumber("1")
            .set_profileid("PROF-12")
            .build()
        )
        result = sender.send_message(enumprofiledeactivation)
        self.assertRegex(result[0], "[0-9a-z]{30,40}", "Should match the transactionId")

    def test_receive_message(self):
        TestReceiver(config).start_stream(confirmation_status=ConfirmationStatus.ALL, offset_persister=TestOffsetPersister)

    @staticmethod
    def _generate_random_dossier_id(operator: str):
        random_int = random.randint(10000, 99999)
        return f'{operator}-{random_int}'


class TestReceiver(Receiver):
    def on_keep_alive(self):
        pass

    def on_porting_request(self, message_id, message):
        print('porting request')
        self.handle_message(message_id, message)

    def on_porting_request_answer(self, message_id, message):
        print('porting request answer')
        self.handle_message(message_id, message)

    def on_porting_request_answer_delayed(self, message_id, message):
        print('porting request answer delayed')
        self.handle_message(message_id, message)

    def on_porting_performed(self, message_id, message):
        print('porting performed')
        self.handle_message(message_id, message)

    def on_deactivation(self, message_id, message):
        print('deactivation')
        self.handle_message(message_id, message)

    def on_cancel(self, message_id, message):
        print('cancel')
        self.handle_message(message_id, message)

    def on_activation_service_number(self, message_id, message):
        print('activation service number')
        self.handle_message(message_id, message)

    def on_deactivation_service_number(self, message_id, message):
        print('deactivation service number')
        self.handle_message(message_id, message)

    def on_tariff_change_service_number(self, message_id, message):
        print('tariff change service number')
        self.handle_message(message_id, message)

    def on_range_activation(self, message_id, message):
        print('range activation')
        self.handle_message(message_id, message)

    def on_range_deactivation(self, message_id, message):
        print('range deactivation')
        self.handle_message(message_id, message)

    def on_enum_activation_number(self, message_id, message):
        print('enum activation number')
        self.handle_message(message_id, message)

    def on_enum_activation_range(self, message_id, message):
        print('enum activation number')
        self.handle_message(message_id, message)

    def on_enum_activation_operator(self, message_id, message):
        print('enum activation number')
        self.handle_message(message_id, message)

    def on_enum_deactivation_number(self, message_id, message):
        print('enum deactivation number')
        self.handle_message(message_id, message)

    def on_enum_deactivation_range(self, message_id, message):
        print('enum deactivation number')
        self.handle_message(message_id, message)

    def on_enum_deactivation_operator(self, message_id, message):
        print('enum deactivation number')
        self.handle_message(message_id, message)

    def on_enum_profile_activation(self, message_id, message):
        print('enum activation profile')
        self.handle_message(message_id, message)

    def on_enum_profile_deactivation(self, message_id, message):
        print('enum deactivation profile')
        self.handle_message(message_id, message)

    def on_error_found(self, message_id, message):
        print('error!')
        self.handle_message(message_id, message)
        self.stop()

    def handle_message(self, message_id, message):
        print(message)
        sender.confirm(message_id)


class TestOffsetPersister(OffsetPersister):
    def __init__(self):
        self._offset = -1

    def get_persisted_offset(self):
        return self._offset

    def persist_offset(self, offset):
        self._offset = offset


if __name__ == '__main__':
    unittest.main()



from coin_sdk.number_portability.domain import MessageType
from coin_sdk.number_portability.messages.common import HeaderCreator
from coin_sdk.number_portability.messages.enum.enum_profile_deactivation import EnumProfileDeactivation
from coin_sdk.number_portability.messages.message import Message
from .enum_profile_deactivation_body import EnumProfileDeactivationBody
from .enum_profile_deactivation_message import EnumProfileDeactivationMessage


class EnumProfileDeactivationBuilder(HeaderCreator):
    def __init__(self):
        super().__init__()
        self._dossierid = None
        self._currentnetworkoperator = None
        self._typeofnumber = None
        self._profileid = None

    def set_dossierid(self, dossierid: str):
        self._dossierid = dossierid
        return self

    def set_currentnetworkoperator(self, currentnetworkoperator: str):
        self._currentnetworkoperator = currentnetworkoperator
        return self

    def set_typeofnumber(self, typeofnumber: str):
        self._typeofnumber = typeofnumber
        return self

    def set_profileid(self, profileid: str):
        self._profileid = profileid
        return self

    def build(self):
        enum_deactivation_number = EnumProfileDeactivation(
            self._dossierid,
            self._currentnetworkoperator,
            self._typeofnumber,
            self._profileid,
        )
        body = EnumProfileDeactivationBody(enum_deactivation_number)
        message = EnumProfileDeactivationMessage(self._header, body)
        return Message(message, MessageType.ENUM_PROFILE_DEACTIVATION_V3)



# coding: utf-8

"""
    COIN Mobile Connect Rest API V3

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 3
    Contact: servicedesk@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from coin_sdk.mobile_connect.v3.domain.link import LinkDto


class SupportedServicesDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'match': 'list[LinkDto]',
        'number_verify': 'list[LinkDto]',
        'account_takeover_protection': 'list[LinkDto]'
    }

    attribute_map = {
        'match': 'match',
        'number_verify': 'numberVerify',
        'account_takeover_protection': 'accountTakeoverProtection'
    }

    def __init__(self, match:list[LinkDto]=None, numberVerify:list[LinkDto]=None, accountTakeoverProtection:list[LinkDto]=None):  # noqa: E501
        """SupportedServicesDto - a model defined in Swagger"""  # noqa: E501
        self._match = None
        self._number_verify = None
        self._account_takeover_protection = None
        self.discriminator = None
        self.match = match
        self.number_verify = numberVerify
        self.account_takeover_protection = accountTakeoverProtection

    @property
    def match(self):
        """Gets the match of this SupportedServicesDto.  # noqa: E501


        :return: The match of this SupportedServicesDto.  # noqa: E501
        :rtype: list[LinkDto]
        """
        return self._match

    @match.setter
    def match(self, match):
        """Sets the match of this SupportedServicesDto.


        :param match: The match of this SupportedServicesDto.  # noqa: E501
        :type: list[LinkDto]
        """
        if match is None:
            raise ValueError("Invalid value for `match`, must not be `None`")  # noqa: E501

        self._match = match

    @property
    def number_verify(self):
        """Gets the number_verify of this SupportedServicesDto.  # noqa: E501


        :return: The number_verify of this SupportedServicesDto.  # noqa: E501
        :rtype: list[LinkDto]
        """
        return self._number_verify

    @number_verify.setter
    def number_verify(self, number_verify):
        """Sets the number_verify of this SupportedServicesDto.


        :param number_verify: The number_verify of this SupportedServicesDto.  # noqa: E501
        :type: list[LinkDto]
        """
        if number_verify is None:
            raise ValueError("Invalid value for `number_verify`, must not be `None`")  # noqa: E501

        self._number_verify = number_verify

    @property
    def account_takeover_protection(self):
        """Gets the account_takeover_protection of this SupportedServicesDto.  # noqa: E501


        :return: The account_takeover_protection of this SupportedServicesDto.  # noqa: E501
        :rtype: list[LinkDto]
        """
        return self._account_takeover_protection

    @account_takeover_protection.setter
    def account_takeover_protection(self, account_takeover_protection):
        """Sets the account_takeover_protection of this SupportedServicesDto.


        :param account_takeover_protection: The account_takeover_protection of this SupportedServicesDto.  # noqa: E501
        :type: list[LinkDto]
        """
        if account_takeover_protection is None:
            raise ValueError("Invalid value for `account_takeover_protection`, must not be `None`")  # noqa: E501

        self._account_takeover_protection = account_takeover_protection

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SupportedServicesDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SupportedServicesDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
